#
# spec file for package aerc
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2023 Hannes Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           aerc
Version:        0.17.0
Release:        3.1
Summary:        An email client for terminals
License:        MIT
Group:          Productivity/Networking/Email/Clients
URL:            https://aerc-mail.org/
Source0:        https://git.sr.ht/~rjarry/aerc/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
Patch0:         fix-script-interpreter.patch
BuildRequires:  gcc
BuildRequires:  golang-packaging
BuildRequires:  make
BuildRequires:  notmuch-devel >= 0.37
BuildRequires:  scdoc
BuildRequires:  zstd
Recommends:     dante
Recommends:     w3m

%description
aerc is an email client that runs in terminals.

%prep
%autosetup -p1 -a1

%build
# Need for cache writes
export HOME=${PWD}

%if "%{_arch}" == "ppc64"
    export GOFLAGS=""
%else
    export GOFLAGS="-buildmode=pie -tags=notmuch"
%endif
%make_build CC=cc DATE="$(date -d "@${SOURCE_DATE_EPOCH}" +%Y-%m-%d)"

%install
%make_install PREFIX=%{_prefix} LIBEXECDIR=%{_libexecdir}/%{name}

%check
%gotest ./...
LC_ALL=C.UTF-8 ./filters/test.sh

%files
%license LICENSE
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_bindir}/%{name}
%{_bindir}/carddav-query
%{_libexecdir}/%{name}
%{_mandir}/man1/aerc.1.gz
%{_mandir}/man1/aerc-search.1.gz
%{_mandir}/man1/carddav-query.1.gz
%{_mandir}/man5/aerc-accounts.5.gz
%{_mandir}/man5/aerc-binds.5.gz
%{_mandir}/man5/aerc-config.5.gz
%{_mandir}/man5/aerc-imap.5.gz
%{_mandir}/man5/aerc-jmap.5.gz
%{_mandir}/man5/aerc-maildir.5.gz
%{_mandir}/man5/aerc-sendmail.5.gz
%{_mandir}/man5/aerc-notmuch.5.gz
%{_mandir}/man5/aerc-smtp.5.gz
%{_mandir}/man7/aerc-patch.7.gz
%{_mandir}/man7/aerc-tutorial.7.gz
%{_mandir}/man7/aerc-templates.7.gz
%{_mandir}/man7/aerc-stylesets.7.gz

%changelog
* Fri May 10 2024 Hannes Braun <apple.hannes@gmail.com>
- Set locale to UTF-8 when testing filters
* Thu Apr 18 2024 Joshua Smith <smolsheep@opensuse.org>
- Build without date to improve reproducibility
- Enable and run tests
* Fri Apr  5 2024 Atri Bhattacharya <badshah400@gmail.com>
- Use full URL for package source (for tarball verification
  purposes).
- Use _service file to collect vendored sources in separate
  vendor.tar.zstd file.
- Set HOME to working dir to allow cache generation.
- Empty %%check section as recommended by rpmlint.
* Thu Feb  1 2024 Hannes Braun <apple.hannes@gmail.com> - 0.17.0
- Update to upstream version 0.17.0
  * New flagged criteria for :sort.
  * New :send-keys command to control embedded terminals.
  * Account aliases now support fnmatch-style wild cards.
  * New :suspend command bound to <C-z> by default.
  * Disable parent context bindings by declaring them empty.
  * Toggle folding with ":fold -t".
  * mail-deleted hook that triggers when a message is removed/moved from a
    folder.
  * mail-added hook that triggers when a message is added to a folder.
  * Improved command completion.
  * Customize key to trigger completion with $complete in binds.conf.
  * Setting complete-min-chars=manual in aerc.conf now disables automatic
    completion, leaving only manually triggered completion.
  * .ThreadUnread is now available in templates.
  * Allow binding commands to Alt+<number> keys.
  * AERC_ACCOUNT and AERC_ADDRESS_BOOK_CMD are now defined in the editor's
    environment when composing a message.
  * Reply with a different account than the current one with ":reply -A
    <account>".
  * New [ui].tab-title-viewer setting to configure the message viewer tab title.
  * The {{.Subject}} template is evaluated to the new option
    [ui].empty-subject if the subject is empty.
  * Change to a folder of another account with ":cf -a <account> <folder>".
  * Patch management with :patch.
  * Add file path to messages in templates as {{.Filename}}.
  * New :menu command to invoke other ex-commands based on a shell command
    output.
  * CLI flags to override paths to config files.
  * Automatically attach signing key with pgp-attach-key in accounts.conf.
  * Copy messages across accounts with ":cp -a <account> <folder>".
  * Move messages across accounts with ":mv -a <account> <folder>".
  * Support the draft flag.
  * Thread arrow prefixes are now fully configurable.
  * colorize support for wild cards "?" and "*".
  * Selection of headers in composer after ":compose -e" followed by ":edit -E".
  * Don't lose child messages of non-queried parents in notmuch threads
  * Notmuch folders defined by the query "*" handle search, filter, and unread
    counts correctly.
  * :open commands are now executed with "sh -c".
  * ":pipe" commands are now executed with "sh -c".
  * Message viewer tab titles will now show "(no subject)" if there is no
    subject in the viewed email.
  * Signature placement is now controlled via the {{.Signature}} template
    variable and not hard coded.
* Thu Sep 28 2023 Hannes Braun <apple.hannes@gmail.com> - 0.16.0
- Update to upstream version 0.16.0
  * JMAP support.
  * The new account wizard now supports all source and outgoing backends.
  * Edit email headers directly in the text editor with "[compose].edit-headers"
    in aerc.conf or with the "-e" flag for all compose related commands (e.g.
    ":compose", ":forward", ":recall", etc.).
  * Use ":save -A" to save all the named parts, not just attachments.
  * The "<Backspace>" key can now be bound.
  * "colorize" can style diff chunk function names with "diff_chunk_func".
  * Warn before sending emails with an empty subject with
    "empty-subject-warning" in aerc.conf.
  * IMAP now uses the delimiter advertised by the server.
  * carddav-query utility to use for "address-book-cmd".
  * Folder name mapping with "folder-map" in accounts.conf.
  * Use ":open -d" to automatically delete temporary files.
  * Remove headers from the compose window with ":header -d <name>".
  * ":attach -r <name> <cmd>" to pipe the attachments from a command.
  * New "msglist_gutter" and `msglist_pill` styles for message list scrollbar.
  * New "%%f" placeholder to "file-picker-cmd" which expands to a location of a
    temporary file from which selected files will be read instead of the
    standard output.
  * Save drafts in custom folders with ":postpone -t <folder>".
  * View "thread-context" in notmuch backends with ":toggle-thread-context".
  * ":archive" now works on servers using a different delimiter.
  * ":save -a" now works with multiple attachments with the same filename.
  * ":open" uses the attachment extension for temporary files, if possible.
  * Fixed memory leak when using notmuch with threading.
  * Names formatted like "Last Name, First Name" are better supported in
    templates
  * Composing an email is now aborted if the text editor exits with an error
    (e.g. with "vim", abort an email with ":cq").
  * Aerc builtin filters path (usually "/usr/libexec/aerc/filters") is now
    prepended to the default system "PATH" to avoid conflicts with installed
    distro binaries which have the same name as aerc builtin filters (e.g.
    "/usr/bin/colorize").
  * ":export-mbox" only exports marked messages, if any. Otherwise it exports
    everything, as usual.
  * The local hostname is no longer exposed in outgoing "Message-Id" headers by
    default. Legacy behaviour can be restored by setting "send-with-hostname
    = true" in accounts.conf.
  * Aerc now has a default style for most UI elements. The "default" styleset is
    now empty. Existing stylesets will only override the default attributes if
    they are set explicitly. To reset the default style and preserve existing
    stylesets appearance, these two lines must be inserted at the beginning:
  * .default=true
  * .normal=true
- Update fix-script-interpreter.patch to patch the shebang of carddav-query
* Sun Aug  6 2023 Joshua Smith <jsmithfpv@gmail.com>
- Add dante and w3m to Recommends due to html filters.
* Thu May 11 2023 Jan Engelhardt <jengelh@inai.de>
- Trim rhetorics from descriptions.
* Thu May 11 2023 Hannes Braun <apple.hannes@gmail.com> - 0.15.2
- Update to upstream version 0.15.2
  * Extra messages disappearing when deleting on maildir.
  * "colorize" and "wrap" filters option parsing on ARM.
* Fri Apr 28 2023 Hannes Braun <apple.hannes@gmail.com> - 0.15.1
- Update to upstream version 0.15.1
  * Fix embedded terminal partial refreshes.
  * Fix maildir message updates after "mbsync".
* Thu Apr 27 2023 Hannes Braun <apple.hannes@gmail.com> - 0.15.0
- Update to upstream version 0.15.0
  * New column-based message list format with "index-columns".
  * Add a "msglist_answered" style for answered messages.
  * Compose "Format=Flowed" messages with "format-flowed=true" in aerc.conf.
  * Add a trimSignature function to the templating engine.
  * Change local domain name for SMTP with "smtp-domain=example.com" in
    aerc.conf
  * New column-based status line format with "status-columns".
  * Inline user-defined styles can be inserted in UI templates via the
    {{.Style "name" string}} function.
  * Add the ability to run arbitrary commands over the socket. This can be
    disabled using the disable-ipc setting.
  * Allow configuring URL handlers via "x-scheme-handler/<scheme> [openers]" in
    aerc.conf.
  * Allow basic shell globbing in [openers] MIME types.
  * Dynamic "msglist_*" styling based on email header values in stylesets.
  * Add "mail-received", "aerc-startup", and "aerc-shutdown" hooks.
  * Search/filter by flags with the "-H" flag.
  * The built-in colorize filter theme is now configured in styleset files into
    the [viewer] section.
  * The standard Usenet signature delimiter "-- " is now prepended to
    "signature-file" and "signature-cmd" if not already present.
  * All aerc(1) commands now interpret aerc-templates(7) markup.
  * running commands (like mailto: or mbox:) no longer prints a success message
  * The built-in colorize filter now emits OSC 8 to mark URLs and emails. Set
    "[general].enable-osc8 = true" in aerc.conf to enable it.
  * [ui].index-format setting has been replaced by index-columns.
  * [statusline].render-format has been replaced by status-columns.
  * Removed support for [ui:subject...] contextual sections in aerc.conf.
  * [triggers] setting has been replaced by [hooks].
  * smtp-starttls setting in accounts.conf has been removed. All smtp://
    transports now assume STARTTLS and will fail if the server does not support
    it. To disable STARTTLS, use smtp+insecure://.
- Remove "filters-install-location.patch: merged into upstream
- Remove "fix-english-typos.patch": merged into upstream
* Sun Mar 26 2023 Hannes Braun <apple.hannes@gmail.com> - 0.14.0
- Fix ppc64 build
* Wed Mar  8 2023 Hannes Braun <apple.hannes@gmail.com> - 0.14.0
- Add group tag
- Add support for systems without a libexec directory
* Tue Jan 31 2023 Hannes Braun <apple.hannes@gmail.com> - 0.14.0
- Initial package creation with version 0.14.0
  * View common email envelope headers with ":envelope".
  * Notmuch accounts now support maildir operations: ":copy", ":move", ":mkdir",
    ":rmdir", ":archive" and the "copy-to" option.
  * Display messages from bottom to top with [ui].reverse-msglist-order=true in
    aerc.conf.
  * Display threads from bottom to top with [ui].reverse-thread-order=true in
    aerc.conf.
  * Style search results in the message list with msglist_result.*.
  * Preview messages with their attachments before sending with ":preview".
  * Filter commands now have AERC_FORMAT, AERC_SUBJECT and AERC_FROM
    defined in their environment.
  * Override the subject prefix for replies pattern with subject-re-pattern in
    accounts.conf.
  * Search/filter by absolute and relative date ranges with the "-d" flag.
  * LIST-STATUS and ORDEREDSUBJECT threading extensions support for imap.
  * Built-in wrap filter that does not mess up nested quotes and lists.
  * Write multipart/alternative messages with ":multipart" and commands defined
    in the new [multipart-converters] section of aerc.conf.
  * Close the message viewer before opening the composer with ":reply -c".
  * Attachment indicator in message list flags (by default a, but can be
    changed via [ui].icon-attachment in aerc.conf).
  * Open file picker menu with ":attach -m". The menu must be generated by an
    external command configured via [compose].file-picker-cmd in aerc.conf.
  * Sample stylesets are now installed in $PREFIX/share/aerc/stylesets.
  * The built-in colorize filter now has different themes.
  * pgp-provider now defaults to auto. It will use the system gpg unless
    the internal keyring exists and contains at least one key.
  * Calling ":split" or ":vsplit" without specifying a size, now attempts to use
    the terminal size to determine a useful split-size.
  * ":pipe -m git am -3" on patch series when Message-Id headers have not been
    generated by "git send-email".
  * Overflowing text in header editors while composing can now be scrolled
    horizontally.
  * Removed broken ":set" command.
